# SzEngineGetEntityByRecordIdResponse

{
"RELATED_ENTITIES": [
{
"ENTITY_ID": "int32",
"ENTITY_NAME": "string",
"ERRULE_CODE": "string",
"IS_AMBIGUOUS": "int32",
"IS_DISCLOSED": "int32",
"MATCH_KEY": "string",
"MATCH_KEY_DETAILS": {
"CONFIRMATIONS": [
{
"ADDITIONAL_SCORES": {
"FULL_SCORE": "int32",
"GENERATION_MATCH": "int32",
"GNR_FN": "int32",
"GNR_GN": "int32",
"GNR_ON": "int32",
"GNR_SN": "int32"
},
"CANDIDATE_FEAT_DESC": "string",
"CANDIDATE_FEAT_ID": "int32",
"CANDIDATE_FEAT_USAGE_TYPE": "string",
"FTYPE_CODE": "string",
"INBOUND_FEAT_DESC": "string",
"INBOUND_FEAT_ID": "int32",
"INBOUND_FEAT_USAGE_TYPE": "string",
"SCORE": "int32",
"SCORE_BEHAVIOR": "string",
"SCORE_BUCKET": "string",
"SOURCE": "string",
"TOKEN": "string"
}
],
"DENIALS": [
{
"ADDITIONAL_SCORES": {
"FULL_SCORE": "int32",
"GENERATION_MATCH": "int32",
"GNR_FN": "int32",
"GNR_GN": "int32",
"GNR_ON": "int32",
"GNR_SN": "int32"
},
"CANDIDATE_FEAT_DESC": "string",
"CANDIDATE_FEAT_ID": "int32",
"CANDIDATE_FEAT_USAGE_TYPE": "string",
"FTYPE_CODE": "string",
"INBOUND_FEAT_DESC": "string",
"INBOUND_FEAT_ID": "int32",
"INBOUND_FEAT_USAGE_TYPE": "string",
"SCORE": "int32",
"SCORE_BEHAVIOR": "string",
"SCORE_BUCKET": "string",
"SOURCE": "string",
"TOKEN": "string"
}
],
"DISCLOSED_RELATIONS": [
{
"DOMAIN": "string",
"ENTITY_ROLES": [
{
"FEAT_DESC": "string",
"ROLE": "string"
}
],
"RELATED_ROLES": [
{
"FEAT_DESC": "string",
"ROLE": "string"
}
],
"REL_LINK": [
{
"DOMAIN": "string",
"FEAT_DESC": "string",
"FEAT_ID": "int32",
"FEAT_USAGE_TYPE": "string",
"FTYPE_CODE": "string",
"LINKED_FEAT_DESC": "string",
"LINKED_FEAT_ID": "int32",
"LINKED_FEAT_TYPE": "string",
"LINKED_FEAT_USAGE_TYPE": "string",
"REL_TYPE": "string"
}
],
"XXX_REL_ANCHOR": [
{
"DOMAIN": "string",
"FEAT_DESC": "string",
"FEAT_ID": "int32",
"LINKED_FEAT_DESC": "string",
"LINKED_FEAT_ID": "int32",
"LINKED_FEAT_TYPE": "string",
"LINKED_FEAT_USAGE_TYPE": "string",
"XXX_REL_POINTER": [
{
"DOMAIN": "string",
"FEAT_DESC": "string",
"FEAT_ID": "int32",
"FEAT_USAGE_TYPE": "string",
"LINKED_FEAT_DESC": "string",
"LINKED_FEAT_ID": "int32",
"LINKED_FEAT_TYPE": "string"
}
]
}
],
"XXX_REL_POINTER": [
{
"DOMAIN": "string",
"FEAT_DESC": "string",
"FEAT_ID": "int32",
"FEAT_USAGE_TYPE": "string",
"LINKED_FEAT_DESC": "string",
"LINKED_FEAT_ID": "int32",
"LINKED_FEAT_TYPE": "string"
}
]
}
],
"REL_LINKS": [
{
"DOMAIN": "string",
"FEAT_DESC": "string",
"FEAT_ID": "int32",
"FEAT_USAGE_TYPE": "string",
"FTYPE_CODE": "string",
"LINKED_FEAT_DESC": "string",
"LINKED_FEAT_ID": "int32",
"LINKED_FEAT_TYPE": "string",
"LINKED_FEAT_USAGE_TYPE": "string",
"REL_TYPE": "string"
}
],
"XXX_ERRULE_CODE": "string"
},
"MATCH_LEVEL": "int32",
"MATCH_LEVEL_CODE": "string",
"RECORDS": [
{
"DATA_SOURCE": "string",
"ERRULE_CODE": "string",
"FEATURES": {
"user_defined_json_key": [
{
"ATTRIBUTES": {
"ACCOUNT_DOMAIN": "string",
"ACCOUNT_NUMBER": "string",
"ADDR_CITY": "string",
"ADDR_COUNTRY": "string",
"ADDR_FULL": "string",
"ADDR_LINE1": "string",
"ADDR_LINE2": "string",
"ADDR_LINE3": "string",
"ADDR_LINE4": "string",
"ADDR_LINE5": "string",
"ADDR_LINE6": "string",
"ADDR_POSTAL_CODE": "string",
"ADDR_STATE": "string",
"ADDR_TYPE": "string",
"CITIZENSHIP": "string",
"DATE_OF_BIRTH": "string",
"DATE_OF_DEATH": "string",
"DRIVERS_LICENSE_NUMBER": "string",
"DRIVERS_LICENSE_STATE": "string",
"DUNS_NUMBER": "string",
"EMAIL_ADDRESS": "string",
"EMPLOYER": "string",
"EMPLOYER_NAME": "string",
"FACEBOOK": "string",
"GENDER": "string",
"GROUP_ASSN_ID_NUMBER": "string",
"GROUP_ASSN_ID_TYPE": "string",
"GROUP_ASSOCIATION_ORG_NAME": "string",
"GROUP_ASSOCIATION_TYPE": "string",
"INSTAGRAM": "string",
"LEI_NUMBER": "string",
"LINKEDIN": "string",
"NAME_FIRST": "string",
"NAME_FULL": "string",
"NAME_LAST": "string",
"NAME_MIDDLE": "string",
"NAME_ORG": "string",
"NAME_PREFIX": "string",
"NAME_SUFFIX": "string",
"NAME_TYPE": "string",
"NATIONALITY": "string",
"NATIONAL_ID_COUNTRY": "string",
"NATIONAL_ID_NUMBER": "string",
"NATIONAL_ID_TYPE": "string",
"NATIVE_NAME_FULL": "string",
"NPI_NUMBER": "string",
"OTHER_ID_COUNTRY": "string",
"OTHER_ID_NUMBER": "string",
"OTHER_ID_TYPE": "string",
"PASSPORT_COUNTRY": "string",
"PASSPORT_NUMBER": "string",
"PHONE_NUMBER": "string",
"PHONE_TYPE": "string",
"PLACE_OF_BIRTH": "string",
"PRIMARY_NAME_FIRST": "string",
"PRIMARY_NAME_FULL": "string",
"PRIMARY_NAME_LAST": "string",
"PRIMARY_NAME_MIDDLE": "string",
"PRIMARY_NAME_ORG": "string",
"RECORD_TYPE": "string",
"REGISTRATION_COUNTRY": "string",
"REGISTRATION_DATE": "string",
"RELATIONSHIP_KEY": "string",
"RELATIONSHIP_TYPE": "string",
"REL_ANCHOR_DOMAIN": "string",
"REL_ANCHOR_KEY": "string",
"REL_POINTER_DOMAIN": "string",
"REL_POINTER_KEY": "string",
"REL_POINTER_ROLE": "string",
"SECONDARY_NAME_ORG": "string",
"SIGNAL": "string",
"SKYPE": "string",
"SSN_NUMBER": "string",
"TANGO": "string",
"TAX_ID_COUNTRY": "string",
"TAX_ID_NUMBER": "string",
"TAX_ID_TYPE": "string",
"TELEGRAM": "string",
"TRUSTED_ID_NUMBER": "string",
"TRUSTED_ID_TYPE": "string",
"TWITTER": "string",
"VIBER": "string",
"WEBSITE_ADDRESS": "string",
"WECHAT": "string",
"WHATSAPP": "string",
"XXX_ADDR_FROM_DATE": "string",
"XXX_ADDR_THRU_DATE": "string",
"XXX_PHONE_FROM_DATE": "string",
"XXX_PHONE_THRU_DATE": "string",
"ZOOMROOM": "string"
},
"CANDIDATE_CAP_REACHED": "string",
"ENTITY_COUNT": "int32",
"FEAT_DESC": "string",
"FEAT_DESC_VALUES": [
{
"ATTRIBUTES": {
"user_defined_json_key": "string"
},
"CANDIDATE_CAP_REACHED": "string",
"ENTITY_COUNT": "int32",
"FEAT_DESC": "string",
"FEAT_DESC_VALUES": [
{
"CANDIDATE_CAP_REACHED": "string",
"ENTITY_COUNT": "int32",
"FEAT_DESC": "string",
"LIB_FEAT_ID": "int32",
"SCORING_CAP_REACHED": "string",
"SUPPRESSED": "string",
"USED_FOR_CAND": "string",
"USED_FOR_SCORING": "string"
}
],
"LIB_FEAT_ID": "int32",
"SCORING_CAP_REACHED": "string",
"SUPPRESSED": "string",
"USED_FOR_CAND": "string",
"USED_FOR_SCORING": "string"
}
],
"LIB_FEAT_ID": "int32",
"SCORING_CAP_REACHED": "string",
"USAGE_TYPE": "string",
"USED_FOR_CAND": "string",
"USED_FOR_SCORING": "string"
}
]
},
"FEATURE_IDS": [
{
"LIB_FEAT_ID": "int32",
"USAGE_TYPE": "string"
}
],
"FIRST_SEEN_DT": "timestamp",
"INTERNAL_ID": "int32",
"JSON_DATA": {
"user_defined_json_key": "object"
},
"LAST_SEEN_DT": "timestamp",
"MATCH_KEY": "string",
"MATCH_LEVEL_CODE": "string",
"RECORD_ID": "string",
"UNMAPPED_DATA": {
"user_defined_json_key": "object"
},
"XXX_ADDRESS_DATA": [
"string"
],
"XXX_ATTRIBUTE_DATA": [
"string"
],
"XXX_ENTITY_DATA": [
"string"
],
"XXX_ENTITY_DESC": "string",
"XXX_ENTITY_KEY": "string",
"XXX_ENTITY_TYPE": "string",
"XXX_IDENTIFIER_DATA": [
"string"
],
"XXX_MATCH_LEVEL": "int32",
"XXX_NAME_DATA": [
"string"
],
"XXX_OTHER_DATA": [
"string"
],
"XXX_PHONE_DATA": [
"string"
],
"XXX_RELATIONSHIP_DATA": [
"string"
]
}
],
"RECORD_SUMMARY": [
{
"DATA_SOURCE": "string",
"RECORD_COUNT": "int32",
"XXX_FIRST_SEEN_DT": "timestamp",
"XXX_LAST_SEEN_DT": "timestamp"
}
],
"RECORD_TYPES": [
"string"
],
"XXX_LAST_SEEN_DT": "timestamp"
}
],
"RESOLVED_ENTITY": {
"ENTITY_ID": "int32",
"ENTITY_NAME": "string",
"FEATURES": {
"user_defined_json_key": [
{
"FEAT_DESC": "string",
"FEAT_DESC_VALUES": [
{
"ATTRIBUTES": {
"user_defined_json_key": "string"
},
"CANDIDATE_CAP_REACHED": "string",
"ENTITY_COUNT": "int32",
"FEAT_DESC": "string",
"FEAT_DESC_VALUES": [
{
"CANDIDATE_CAP_REACHED": "string",
"ENTITY_COUNT": "int32",
"FEAT_DESC": "string",
"LIB_FEAT_ID": "int32",
"SCORING_CAP_REACHED": "string",
"SUPPRESSED": "string",
"USED_FOR_CAND": "string",
"USED_FOR_SCORING": "string"
}
],
"LIB_FEAT_ID": "int32",
"SCORING_CAP_REACHED": "string",
"SUPPRESSED": "string",
"USED_FOR_CAND": "string",
"USED_FOR_SCORING": "string"
}
],
"LIB_FEAT_ID": "int32",
"USAGE_TYPE": "string",
"XXX_ATTRIBUTES": [
{
"ACCOUNT_DOMAIN": "string",
"ACCOUNT_NUMBER": "string",
"ADDR_CITY": "string",
"ADDR_COUNTRY": "string",
"ADDR_FULL": "string",
"ADDR_LINE1": "string",
"ADDR_LINE2": "string",
"ADDR_LINE3": "string",
"ADDR_LINE4": "string",
"ADDR_LINE5": "string",
"ADDR_LINE6": "string",
"ADDR_POSTAL_CODE": "string",
"ADDR_STATE": "string",
"ADDR_TYPE": "string",
"CITIZENSHIP": "string",
"DATE_OF_BIRTH": "string",
"DATE_OF_DEATH": "string",
"DRIVERS_LICENSE_NUMBER": "string",
"DRIVERS_LICENSE_STATE": "string",
"DUNS_NUMBER": "string",
"EMAIL_ADDRESS": "string",
"EMPLOYER": "string",
"EMPLOYER_NAME": "string",
"FACEBOOK": "string",
"GENDER": "string",
"GROUP_ASSN_ID_NUMBER": "string",
"GROUP_ASSN_ID_TYPE": "string",
"GROUP_ASSOCIATION_ORG_NAME": "string",
"GROUP_ASSOCIATION_TYPE": "string",
"INSTAGRAM": "string",
"LEI_NUMBER": "string",
"LINKEDIN": "string",
"NAME_FIRST": "string",
"NAME_FULL": "string",
"NAME_LAST": "string",
"NAME_MIDDLE": "string",
"NAME_ORG": "string",
"NAME_PREFIX": "string",
"NAME_SUFFIX": "string",
"NAME_TYPE": "string",
"NATIONALITY": "string",
"NATIONAL_ID_COUNTRY": "string",
"NATIONAL_ID_NUMBER": "string",
"NATIONAL_ID_TYPE": "string",
"NATIVE_NAME_FULL": "string",
"NPI_NUMBER": "string",
"OTHER_ID_COUNTRY": "string",
"OTHER_ID_NUMBER": "string",
"OTHER_ID_TYPE": "string",
"PASSPORT_COUNTRY": "string",
"PASSPORT_NUMBER": "string",
"PHONE_NUMBER": "string",
"PHONE_TYPE": "string",
"PLACE_OF_BIRTH": "string",
"PRIMARY_NAME_FIRST": "string",
"PRIMARY_NAME_FULL": "string",
"PRIMARY_NAME_LAST": "string",
"PRIMARY_NAME_MIDDLE": "string",
"PRIMARY_NAME_ORG": "string",
"RECORD_TYPE": "string",
"REGISTRATION_COUNTRY": "string",
"REGISTRATION_DATE": "string",
"RELATIONSHIP_KEY": "string",
"RELATIONSHIP_TYPE": "string",
"REL_ANCHOR_DOMAIN": "string",
"REL_ANCHOR_KEY": "string",
"REL_POINTER_DOMAIN": "string",
"REL_POINTER_KEY": "string",
"REL_POINTER_ROLE": "string",
"SECONDARY_NAME_ORG": "string",
"SIGNAL": "string",
"SKYPE": "string",
"SSN_NUMBER": "string",
"TANGO": "string",
"TAX_ID_COUNTRY": "string",
"TAX_ID_NUMBER": "string",
"TAX_ID_TYPE": "string",
"TELEGRAM": "string",
"TRUSTED_ID_NUMBER": "string",
"TRUSTED_ID_TYPE": "string",
"TWITTER": "string",
"VIBER": "string",
"WEBSITE_ADDRESS": "string",
"WECHAT": "string",
"WHATSAPP": "string",
"XXX_ADDR_FROM_DATE": "string",
"XXX_ADDR_THRU_DATE": "string",
"XXX_PHONE_FROM_DATE": "string",
"XXX_PHONE_THRU_DATE": "string",
"ZOOMROOM": "string"
}
]
}
]
},
"RECORDS": [
{
"DATA_SOURCE": "string",
"ERRULE_CODE": "string",
"FEATURES": {
"user_defined_json_key": [
{
"ATTRIBUTES": {
"ACCOUNT_DOMAIN": "string",
"ACCOUNT_NUMBER": "string",
"ADDR_CITY": "string",
"ADDR_COUNTRY": "string",
"ADDR_FULL": "string",
"ADDR_LINE1": "string",
"ADDR_LINE2": "string",
"ADDR_LINE3": "string",
"ADDR_LINE4": "string",
"ADDR_LINE5": "string",
"ADDR_LINE6": "string",
"ADDR_POSTAL_CODE": "string",
"ADDR_STATE": "string",
"ADDR_TYPE": "string",
"CITIZENSHIP": "string",
"DATE_OF_BIRTH": "string",
"DATE_OF_DEATH": "string",
"DRIVERS_LICENSE_NUMBER": "string",
"DRIVERS_LICENSE_STATE": "string",
"DUNS_NUMBER": "string",
"EMAIL_ADDRESS": "string",
"EMPLOYER": "string",
"EMPLOYER_NAME": "string",
"FACEBOOK": "string",
"GENDER": "string",
"GROUP_ASSN_ID_NUMBER": "string",
"GROUP_ASSN_ID_TYPE": "string",
"GROUP_ASSOCIATION_ORG_NAME": "string",
"GROUP_ASSOCIATION_TYPE": "string",
"INSTAGRAM": "string",
"LEI_NUMBER": "string",
"LINKEDIN": "string",
"NAME_FIRST": "string",
"NAME_FULL": "string",
"NAME_LAST": "string",
"NAME_MIDDLE": "string",
"NAME_ORG": "string",
"NAME_PREFIX": "string",
"NAME_SUFFIX": "string",
"NAME_TYPE": "string",
"NATIONALITY": "string",
"NATIONAL_ID_COUNTRY": "string",
"NATIONAL_ID_NUMBER": "string",
"NATIONAL_ID_TYPE": "string",
"NATIVE_NAME_FULL": "string",
"NPI_NUMBER": "string",
"OTHER_ID_COUNTRY": "string",
"OTHER_ID_NUMBER": "string",
"OTHER_ID_TYPE": "string",
"PASSPORT_COUNTRY": "string",
"PASSPORT_NUMBER": "string",
"PHONE_NUMBER": "string",
"PHONE_TYPE": "string",
"PLACE_OF_BIRTH": "string",
"PRIMARY_NAME_FIRST": "string",
"PRIMARY_NAME_FULL": "string",
"PRIMARY_NAME_LAST": "string",
"PRIMARY_NAME_MIDDLE": "string",
"PRIMARY_NAME_ORG": "string",
"RECORD_TYPE": "string",
"REGISTRATION_COUNTRY": "string",
"REGISTRATION_DATE": "string",
"RELATIONSHIP_KEY": "string",
"RELATIONSHIP_TYPE": "string",
"REL_ANCHOR_DOMAIN": "string",
"REL_ANCHOR_KEY": "string",
"REL_POINTER_DOMAIN": "string",
"REL_POINTER_KEY": "string",
"REL_POINTER_ROLE": "string",
"SECONDARY_NAME_ORG": "string",
"SIGNAL": "string",
"SKYPE": "string",
"SSN_NUMBER": "string",
"TANGO": "string",
"TAX_ID_COUNTRY": "string",
"TAX_ID_NUMBER": "string",
"TAX_ID_TYPE": "string",
"TELEGRAM": "string",
"TRUSTED_ID_NUMBER": "string",
"TRUSTED_ID_TYPE": "string",
"TWITTER": "string",
"VIBER": "string",
"WEBSITE_ADDRESS": "string",
"WECHAT": "string",
"WHATSAPP": "string",
"XXX_ADDR_FROM_DATE": "string",
"XXX_ADDR_THRU_DATE": "string",
"XXX_PHONE_FROM_DATE": "string",
"XXX_PHONE_THRU_DATE": "string",
"ZOOMROOM": "string"
},
"CANDIDATE_CAP_REACHED": "string",
"ENTITY_COUNT": "int32",
"FEAT_DESC": "string",
"FEAT_DESC_VALUES": [
{
"ATTRIBUTES": {
"user_defined_json_key": "string"
},
"CANDIDATE_CAP_REACHED": "string",
"ENTITY_COUNT": "int32",
"FEAT_DESC": "string",
"FEAT_DESC_VALUES": [
{
"CANDIDATE_CAP_REACHED": "string",
"ENTITY_COUNT": "int32",
"FEAT_DESC": "string",
"LIB_FEAT_ID": "int32",
"SCORING_CAP_REACHED": "string",
"SUPPRESSED": "string",
"USED_FOR_CAND": "string",
"USED_FOR_SCORING": "string"
}
],
"LIB_FEAT_ID": "int32",
"SCORING_CAP_REACHED": "string",
"SUPPRESSED": "string",
"USED_FOR_CAND": "string",
"USED_FOR_SCORING": "string"
}
],
"LIB_FEAT_ID": "int32",
"SCORING_CAP_REACHED": "string",
"USAGE_TYPE": "string",
"USED_FOR_CAND": "string",
"USED_FOR_SCORING": "string"
}
]
},
"FEATURE_IDS": [
{
"LIB_FEAT_ID": "int32",
"USAGE_TYPE": "string"
}
],
"FIRST_SEEN_DT": "timestamp",
"INTERNAL_ID": "int32",
"JSON_DATA": {
"user_defined_json_key": "object"
},
"LAST_SEEN_DT": "timestamp",
"MATCH_KEY": "string",
"MATCH_LEVEL_CODE": "string",
"RECORD_ID": "string",
"UNMAPPED_DATA": {
"user_defined_json_key": "object"
},
"XXX_ADDRESS_DATA": [
"string"
],
"XXX_ATTRIBUTE_DATA": [
"string"
],
"XXX_ENTITY_DATA": [
"string"
],
"XXX_ENTITY_DESC": "string",
"XXX_ENTITY_KEY": "string",
"XXX_ENTITY_TYPE": "string",
"XXX_IDENTIFIER_DATA": [
"string"
],
"XXX_MATCH_LEVEL": "int32",
"XXX_NAME_DATA": [
"string"
],
"XXX_OTHER_DATA": [
"string"
],
"XXX_PHONE_DATA": [
"string"
],
"XXX_RELATIONSHIP_DATA": [
"string"
]
}
],
"RECORD_SUMMARY": [
{
"DATA_SOURCE": "string",
"RECORD_COUNT": "int32",
"XXX_FIRST_SEEN_DT": "timestamp",
"XXX_LAST_SEEN_DT": "timestamp"
}
],
"RECORD_TYPES": [
"string"
],
"XXX_ERRULE_CODE": "string",
"XXX_FEATURE_IDS": [
{
"LIB_FEAT_ID": "int32",
"USAGE_TYPE": "string"
}
],
"XXX_IS_AMBIGUOUS": "int32",
"XXX_IS_DISCLOSED": "int32",
"XXX_LAST_SEEN_DT": "timestamp",
"XXX_MATCH_KEY": "string",
"XXX_MATCH_LEVEL": "int32",
"XXX_MATCH_LEVEL_CODE": "string"
}
}